@@ -72,7 +72,12 @@ class JsonRPCServer(Generic[TProtocol], abc.ABC):
         self._in_closing = False
         self._closed = False
 
-        self.loop = asyncio.get_event_loop()
+        try:
+            self.loop = asyncio.get_event_loop()
+        except RuntimeError:
+            self.loop = asyncio.new_event_loop()
+            asyncio.set_event_loop(self.loop)
+
         if self.loop is not None:
             self.loop.slow_callback_duration = 10
 
@@ -198,7 +203,6 @@ class JsonRPCServer(Generic[TProtocol], abc.ABC):
                             stop_event.wait(0.01)
 
                 with ThreadPoolExecutor(max_workers=1, thread_name_prefix="aio_readline") as stdio_executor:
-                    self._stdio_threadpool = stdio_executor
                     await asyncio.wrap_future(stdio_executor.submit(run))
 
             self.loop.run_until_complete(aio_readline(transport.rfile, protocol))
